from distutils.core import setup

setup(
	name		= 'mpip_nester',
	version		= '1.2.0',
	py_modules	= ['mpip_nester'],
	author		= 'mpippins52',
	author_email	= 'mpippins52@gmail.com',
	url		= 'http://www.mpippins52.com',
	description	= 'A simple printer of nested lists',
     )
